import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

//Define the number format in legend
const numberFormat = (number) =>
  (Math.abs(Number(number)) / 1.0e6).toFixed(2) +
  ' Million';

//Define pie chart structure
const render = (data) => {
  const pieData = pie()
    .sort(null)
    .value((d) => d.DEM)(data);
  const colors = scaleOrdinal(schemeCategory10);
  const segments = arc()
    .innerRadius(0)
    .outerRadius(200)
    .padAngle(0)
    .padRadius(0);

  const sections = svg
    .append('g')
    .attr('transform', `translate(250,250)`)
    .selectAll('path')
    .data(pieData);
  sections
    .enter()
    .append('path')
    .attr('d', segments)
    .attr('fill', (d) => colors(d.data.DEM))
    .on('mouseover', (d) => console.log(d.data.DEM));

  const legends = svg
    .append('g')
    .attr('transform', 'translate(500,100)')
    .selectAll('.legends')
    .data(pieData);
  const legend = legends
    .enter()
    .append('g')
    .classed('.legends', true)
    .attr('transform', (d, i) => {
      return `translate(0,${(i + 1) * 30})`;
    });

  //Define legend
  legend
    .append('rect')
    .attr('width', 20)
    .attr('height', 20)
    .attr('fill', (d) => colors(d.data.DEM));
  legend
    .append('text')
    .attr('x', 25)
    .attr('y', 15)
    .attr('class', 'legend_text')
    .text((d) => d.data.state);
  legend
    .append('text')
    .attr('x', 250)
    .attr('y', 15)
    .attr('class', 'legend_value')
    .text((d) => numberFormat(d.data.DEM));
};

//Democrat population csv
const csvUrl =
  'https://gist.githubusercontent.com/Sruthi1003/0dff95563c57b8af419d36c33904aef9/raw/5ca2c7f5a71a58e030e7bcea9fcfa1a494eb2a6b/Countrydata.csv';

//Load the data and select top 10 entries
csv(csvUrl).then((csvData) => {
  csvData.sort((data1, data2) => data2.DEM - data1.DEM);
  if (csvData) {
    render(csvData.slice(0, 10));
  }
});
